@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2004-2006 Peter Graves
  * Copyright (C) 2008 Hideo at Yokohama
- * $Id: FileStream.java 13444 2011-08-06 13:51:26Z ehuelsmann $
+ * $Id$
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -233,15 +233,17 @@ public final class FileStream extends Stream
     protected boolean _setFilePosition(LispObject arg)
     {
         try {
-            long pos;
+            long pos = 0;
             if (arg == Keyword.START)
                 pos = 0;
             else if (arg == Keyword.END)
                 pos = racf.length();
-            else {
-                long n = Fixnum.getValue(arg); // FIXME arg might be a bignum
-                pos = n * bytesPerUnit;
-            }
+            else if (arg instanceof Fixnum)
+                pos = ((Fixnum) arg).value * bytesPerUnit;
+            else if (arg instanceof Bignum)
+                pos = ((Bignum) arg).longValue() * bytesPerUnit;
+            else
+                type_error(arg, Symbol.INTEGER);
             racf.position(pos);
         }
         catch (IOException e) {
