@@ -2,7 +2,7 @@
  * JavaObject.java
  *
  * Copyright (C) 2002-2005 Peter Graves
- * $Id: JavaObject.java 14600 2014-01-09 11:22:38Z mevenson $
+ * $Id$
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -407,7 +407,7 @@ public final class JavaObject extends LispObject {
                 int length = Array.getLength(obj);
                 for (int i = 0; i < length; i++) {
                     parts = parts
-                        .push(new Cons(new SimpleString(i), 
+		      .push(new Cons(new SimpleString(String.valueOf(i)), 
                                        JavaObject.getInstance(Array.get(obj, i))));
                 }
             } else {
@@ -599,22 +599,26 @@ public final class JavaObject extends LispObject {
         return sb.toString();
     }
 
-    // ### describe-java-object
-    private static final Primitive DESCRIBE_JAVA_OBJECT =
-        new Primitive("describe-java-object", PACKAGE_JAVA, true)
-    {
-        @Override
-        public LispObject execute(LispObject first, LispObject second)
-
-        {
-            if (!(first instanceof JavaObject))
-                return type_error(first, Symbol.JAVA_OBJECT);
-            final Stream stream = checkStream(second);
-            final JavaObject javaObject = (JavaObject) first;
-            stream._writeString(describeJavaObject(javaObject));
-            return LispThread.currentThread().nothing();
-        }
-    };
+  private static final Primitive DESCRIBE_JAVA_OBJECT 
+    = new pf_describe_java_object();
+  @DocString(name="describe-java-object",
+	     args="object stream",
+	     doc="Print a human friendly description of Java OBJECT to STREAM.")
+  private static final class pf_describe_java_object extends Primitive 
+  {
+    pf_describe_java_object() {
+      super("describe-java-object", PACKAGE_JAVA, true);
+    }
+    @Override
+    public LispObject execute(LispObject first, LispObject second) {
+      if (!(first instanceof JavaObject))
+	return type_error(first, Symbol.JAVA_OBJECT);
+      final Stream stream = checkStream(second);
+      final JavaObject javaObject = (JavaObject) first;
+      stream._writeString(describeJavaObject(javaObject));
+      return LispThread.currentThread().nothing();
+    }
+  };
 
     //JAVA-CLASS support
 
