@@ -128,9 +128,14 @@ public class LispObject //extends Lisp
 
   public Object javaInstance(Class<?> c)
   {
-      if (c.isAssignableFrom(getClass()))
-	  return this;
-      return error(new LispError("The value " + princToString() +
+    if (c.isAssignableFrom(getClass())) {
+      return this;
+    }
+
+    if (c == Boolean.class || c == boolean.class)
+      return Boolean.TRUE;
+
+    return error(new LispError("The value " + princToString() +
 				 " is not of class " + c.getName()));
   }
 
