@@ -2,7 +2,7 @@
  * Stream.java
  *
  * Copyright (C) 2003-2007 Peter Graves
- * $Id: Stream.java 14466 2013-04-24 12:50:40Z rschlatte $
+ * $Id$
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -396,7 +396,7 @@ public class Stream extends StructureObject {
     SortedMap<String, Charset> available = Charset.availableCharsets();
     Set<String> encodings = available.keySet();
     for (String charset : encodings) {
-      result.add(new Symbol(charset, PACKAGE_KEYWORD));
+      result.add (PACKAGE_KEYWORD.intern (charset));
     }
     return result;
   }
@@ -1190,16 +1190,17 @@ public class Stream extends StructureObject {
                     return symbol;
 
                 // Error!
-                if (pkg.findInternalSymbol(symbolName) != null)
-                    return error(new ReaderError("The symbol \"" + symbolName +
-                                                 "\" is not external in package " +
-                                                 packageName + '.',
-                                                 this));
-                else
-                    return error(new ReaderError("The symbol \"" + symbolName +
-                                                 "\" was not found in package " +
-                                                 packageName + '.',
-                                                 this));
+                if (pkg.findInternalSymbol(symbolName) != null) {
+                    return error(new ReaderError("The symbol \"~A\" is not external in package ~A.",
+                                                 this,
+                                                 new SimpleString(symbolName),
+                                                 new SimpleString(packageName)));
+                } else {
+                    return error(new ReaderError("The symbol \"~A\" was not found in package ~A.",
+                                                 this,
+                                                 new SimpleString(symbolName),
+                                                 new SimpleString(packageName)));
+                }
             }
         } else {                // token.length == 0
             Package pkg = (Package)Symbol._PACKAGE_.symbolValue(thread);
