@@ -1,7 +1,7 @@
 ;;; compile-system.lisp
 ;;;
 ;;; Copyright (C) 2004-2008 Peter Graves
-;;; $Id: compile-system.lisp 14817 2015-09-15 13:19:02Z mevenson $
+;;; $Id$
 ;;;
 ;;; This program is free software; you can redistribute it and/or
 ;;; modify it under the terms of the GNU General Public License
@@ -317,6 +317,8 @@
       (load (do-compile "concatenate.lisp"))
       (load (do-compile "ldb.lisp"))
       (load (do-compile "destructuring-bind.lisp"))
+      (load (do-compile "featurep.lisp"))
+
       ;; But not for these.
       (mapc #'do-compile '("adjoin.lisp"
                            "and.lisp"
@@ -368,10 +370,10 @@
                            "error.lisp"
                            "extensible-sequences.lisp"
                            "fasl-concat.lisp"
-                           "featurep.lisp"
                            "fdefinition.lisp"
                            "fill.lisp"
                            "find-all-symbols.lisp"
+                           "get-pid.lisp"
                            "gentemp.lisp"
                            "gray-streams.lisp"
                            "gui.lisp"
