@@ -2,7 +2,7 @@
  * unzip.java
  *
  * Copyright (C) 2010 Mark Evenson
- * $Id: unzip.java 13944 2012-05-24 11:11:43Z mevenson $
+ * $Id$
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -44,7 +44,7 @@ import java.util.zip.ZipFile;
 
 @DocString(name="unzip",
            args="pathname &optional directory => unzipped_pathnames",
-           doc="Unpack zip archive at PATHNAME returning a list of extracted pathnames.\nIf the optional DIRECTORY is specified, root the abstraction in that directory, otherwise use the current value of *DEFAULT-PATHNAME-DEFAULTS.")
+           doc="Unpack zip archive at PATHNAME returning a list of extracted pathnames.\nIf the optional DIRECTORY is specified, root the abstraction in that directory, otherwise use the current value of *DEFAULT-PATHNAME-DEFAULTS*.")
 public final class unzip 
   extends Primitive
 {
